
# Slot: annotations


a collection of tag/text tuples with the semantics of OWL Annotation

URI: [linkml:annotations](https://w3id.org/linkml/annotations)


## Domain and Range

[Annotatable](Annotatable.md) &#8594;  <sub>0..\*</sub> [Annotation](Annotation.md)

## Parents

 *  is_a: [extensions](extensions.md)

## Children


## Used by

 * [Annotatable](Annotatable.md)
 * [Annotation](Annotation.md)
 * [ClassDefinition](ClassDefinition.md)
 * [Definition](Definition.md)
 * [Element](Element.md)
 * [EnumDefinition](EnumDefinition.md)
 * [PermissibleValue](PermissibleValue.md)
 * [SchemaDefinition](SchemaDefinition.md)
 * [SlotDefinition](SlotDefinition.md)
 * [SubsetDefinition](SubsetDefinition.md)
 * [TypeDefinition](TypeDefinition.md)
 * [UniqueKey](UniqueKey.md)
